@@ -9,7 +9,6 @@ class is the base class adapting `Raven` to work with the Ostrich calibration to
 import collections
 import csv
 import datetime as dt
-import operator
 import os
 import re
 import shutil
@@ -21,19 +20,12 @@ from collections import OrderedDict
 from dataclasses import astuple, fields, is_dataclass, replace
 from pathlib import Path
 from typing import Any, Dict, List, Union, cast
+from warnings import warn
 
 import numpy as np
 import xarray as xr
 from numpy.distutils.misc_util import is_sequence
 
-import ravenpy
-from ravenpy.config.commands import (
-    DataCommand,
-    GriddedForcingCommand,
-    HRUsCommand,
-    ObservationDataCommand,
-    StationForcingCommand,
-)
 from ravenpy.config.rvs import RVC, Config
 
 RAVEN_EXEC_PATH = os.getenv("RAVENPY_RAVEN_BINARY_PATH") or shutil.which("raven")
@@ -51,6 +43,15 @@ class RavenError(Exception):
     pass
 
 
+class RavenWarning(Warning):
+    """
+    This is a warning corresponding to a message of type "WARNING" in the Raven_errors.txt
+    file resulting from a Raven (i.e. the C program) run.
+    """
+
+    pass
+
+
 class Raven:
     """RAVEN hydrological model wrapper.
 
@@ -61,18 +62,6 @@ class Raven:
     r.configure()
     """
 
-    _parallel_parameters = [
-        "params",
-        "hru_state",
-        "basin_state",
-        "nc_index",
-        "area",
-        "elevation",
-        "latitude",
-        "longitude",
-        "region_id",
-    ]
-
     # This is just to satisfy mypy, which wants to know about this internal class defined
     # by the emulators (which are Raven subclasses)
     Params: Any
@@ -109,7 +98,13 @@ class Raven:
         else:
             raise AttributeError(f"Raven version not found: {out}")
 
-        self.workdir = Path(workdir or tempfile.mkdtemp())
+        # Remove this file that has been produced by the previous raven call to get the version
+        try:
+            os.remove("Raven_errors.txt")
+        except OSError:
+            pass
+
+        self.workdir = Path(os.path.realpath(workdir or tempfile.mkdtemp()))
 
         # Individual files for all simulations
         self.ind_outputs: Dict[str, List[Path]] = {}
@@ -148,7 +143,7 @@ class Raven:
 
     @property
     def model_path(self):
-        return self.exec_path / self.model_dir / "p{:02}".format(self.psim)
+        return self.exec_path / self.model_dir / f"p{self.psim:02}"
 
     @property
     def raven_cmd(self):
@@ -251,8 +246,6 @@ class Raven:
         ----------
         ts : sequence
           Paths to input forcing files.
-        index : int
-          Run index (starts at 1)
         """
         # Compute derived parameters
         self.derived_parameters()
@@ -267,7 +260,7 @@ class Raven:
         # Create symbolic link to input files
         for fn in ts:
             if not (self.model_path / Path(fn).name).exists():
-                os.symlink(str(fn), str(self.model_path / Path(fn).name))
+                os.symlink(os.path.realpath(fn), str(self.model_path / Path(fn).name))
 
         # Create symbolic link to Raven executable
         if not self.raven_cmd.exists():
@@ -275,7 +268,7 @@ class Raven:
 
         return self.bash_cmd
 
-    def run(self, ts, overwrite=False, **kwds):
+    def run(self, ts, overwrite=False, parallel={}, **kwds):
         """Run the model.
 
         Parameters
@@ -283,7 +276,9 @@ class Raven:
         ts : path or sequence
           Sequence of input file paths. Symbolic links to those files will be created in the model directory.
         overwrite : bool
-          Whether or not to overwrite existing model and output files.
+          Whether to overwrite existing model and output files.
+        parallel : {}
+          Parameters that should be distributed across parallel simulations.
         **kwds : dict
           Raven parameters used to fill configuration file templates.
 
@@ -294,7 +289,7 @@ class Raven:
         Examples
         --------
         >>> r = Raven()
-        >>> r.configure(rvi='path to template', rvp='...'}
+        >>> r.configure(rvi="path/to/template", rvp="...")
         >>> r.run(ts, start_date=dt.datetime(2000, 1, 1), area=1000, X1=67)
 
         """
@@ -312,48 +307,21 @@ class Raven:
             assert len(self.config.rvh.hrus) == 1
             self.config.rvh.hrus = (replace(self.config.rvh.hrus[0], **hru_attrs),)
 
-        # Case for potentially parallel parameters
-        pdict = {}
-        for p in self._parallel_parameters:
-            val = kwds.pop(p, None)
-            if val is not None and p == "params":
-                assert hasattr(self, "Params")  # make sure we are in an emulator
-                # Special case where we have `Params(..)` or `[Params(), ..]`
-                lval = [val] if not is_sequence(val) else val
-                if isinstance(lval[0], self.Params):
-                    pdict[p] = np.atleast_1d(val)
-                else:
-                    pdict[p] = np.atleast_2d(val)
-            else:
-                pdict[p] = np.atleast_1d(val)
+        # Parallel parameters handling
+        plen = {p: len(v) for (p, v) in parallel.items()}
+        if len(set(plen.values())) > 1:
+            raise ValueError("All parallel parameters should have the same length.")
 
-        # Number of parallel loops is dictated by the number of parallel parameters or nc_index.
-        plen = {pp: len(pdict[pp]) for pp in self._parallel_parameters + ["nc_index"]}
+        nloops = max(plen.values()) if plen else 1
 
-        # Find the longest parallel array and its length
-        longer, nloops = max(plen.items(), key=operator.itemgetter(1))
-
-        # Assign the name of the parallel dimension
-        # nbasins is set by RavenC++
-        if nloops > 1:
-            self._pdim = {
-                "params": "params",
-                "hru_state": "state",
-                "basin_state": "state",
-                "nc_index": "nbasins",
-            }[longer]
-
-        for key, val in pdict.items():
-            if len(val) not in [1, nloops]:
-                raise ValueError(
-                    "Parameter {} has incompatible dimension: {}. "
-                    "Should be 1 or {}.".format(key, len(val), nloops)
-                )
-
-        # Resize parallel parameters to the largest size
-        for key, val in pdict.items():
-            if len(val) == 1:
-                pdict[key] = val.repeat(nloops, axis=0)
+        if "params" in parallel.keys():
+            self._pdim = "params"
+        elif "hru_state" in parallel.keys() or "basin_state" in parallel.keys():
+            self._pdim = "state"
+        elif "nc_index" in parallel.keys():
+            self._pdim = "nbasins"
+        else:
+            self._pdim = "pdim"
 
         # Use rvc file to set model state, if any
         rvc = kwds.pop("rvc", None)
@@ -375,7 +343,7 @@ class Raven:
         # Loop over parallel parameters - sets self.rvi.run_index
         procs = []
         for self.psim in range(nloops):
-            for key, val in pdict.items():
+            for key, val in parallel.items():
                 if val[self.psim] is not None:
                     if key == "hru_state":
                         self.config.rvc.set_hru_state(val[self.psim])
@@ -398,10 +366,14 @@ class Raven:
 
         return procs
 
-    def __call__(self, ts, overwrite=False, **kwds):
+    def _execute(self, ts, overwrite=False, parallel={}, **kwds):
+        """
+        parallel : {}
+          Parameters that should be distributed across parallel simulations.
+        """
         self.setup(overwrite)
 
-        procs = self.run(ts, overwrite, **kwds)
+        procs = self.run(ts, overwrite, parallel=parallel, **kwds)
 
         for proc in procs:
             # When Raven errors right away (for instance if it's missing an RV file)
@@ -414,8 +386,13 @@ class Raven:
         if messages["ERROR"]:
             raise RavenError("\n".join(messages["ERROR"]))
 
+        for msg in messages["WARNING"]:
+            warn(msg, category=RavenWarning)
+
         assert messages["SIMULATION COMPLETE"]
 
+    def __call__(self, ts, overwrite=False, parallel={}, **kwds):
+        self._execute(ts, overwrite=overwrite, parallel=parallel, **kwds)
         self.parse_results()
 
     def resume(self, solution=None):
@@ -439,6 +416,7 @@ class Raven:
         # name.
         path = path or self.exec_path
         run_name = run_name or self.config.rvi.run_name or ""
+
         patterns = {
             "hydrograph": f"{run_name}*Hydrographs.nc",
             "storage": f"{run_name}*WatershedStorage.nc",
@@ -455,10 +433,10 @@ class Raven:
                     raise exc
                 else:
                     continue
+                fns = []
 
-            fns.sort()
             self.ind_outputs[key] = fns
-            self.outputs[key] = self._merge_output(fns, pattern[1:])
+            self.outputs[key] = self._merge_output(fns, pattern.replace("*", "_ALL_"))
 
         self.outputs["rv_config"] = self._merge_output(self._rv_paths, "rv.zip")
 
@@ -486,6 +464,10 @@ class Raven:
         # Let's zip the files that could not be merged.
         outfn = outfn.with_suffix(".zip")
 
+        # Remove any existing file, otherwise content will be appended to it.
+        if outfn.exists():
+            outfn.unlink()
+
         # Find the lower file parts level at which there are differences among files.
         i = get_diff_level(files)
 
@@ -536,9 +518,11 @@ class Raven:
 
         if len(files) == 0:
             if not self.config.rvi.suppress_output:
-                raise UserWarning("No output files for {} in {}.".format(pattern, path))
+                raise UserWarning(f"No output files for {pattern} in {path}.")
 
-        return [f.absolute() for f in files]
+        fns = [f.absolute() for f in files]
+        fns.sort()
+        return fns
 
     @property
     def q_sim(self):
@@ -613,9 +597,14 @@ class Raven:
         """Return a nested dictionary of performance metrics keyed by diagnostic name and period. The default period
         is called "ALL".
         """
+        run_name = self.config.rvi.run_name or ""
+        pattern = f"{run_name}*Diagnostics.csv"
+
         diag = []
         out = collections.defaultdict(list)
-        for fn in self.ind_outputs["diagnostics"]:
+        fns = self._get_output(pattern, path=self.exec_path)
+
+        for fn in fns:
             with open(fn) as f:
                 reader = csv.reader(f.readlines())
                 header = next(reader)
@@ -646,7 +635,7 @@ class Ostrich(Raven):
 
     Examples
     --------
-    >>> r = Ostrich('/tmp/testdir')
+    >>> r = Ostrich("/tmp/testdir")
     >>> r.configure()
     """
 
