@@ -10,6 +10,15 @@ from ravenpy.models.base import Ostrich, Raven
 
 
 class HMETS(Raven):
+    """Hydrology Model - École de technologie supérieure (HMETS)
+
+    References
+    ----------
+    Martel, J.-L., Demeester, K., Brissette, F., Arsenault, R., Poulin, A. 2017.
+    HMETS: A simple and efficient hydrology model for teaching hydrological modelling,
+    flow forecasting and climate change impacts. Int. J. Eng. Educ., 33, 1307–1316.
+    """
+
     @dataclass
     class Params:
         GAMMA_SHAPE: float
