@@ -12,6 +12,18 @@ from .gr4jcn import GR4JCN
 
 
 class MOHYSE(Raven):
+    """Modèle Hydrologique Simplifié à l'Extrême (MOHYSE)
+
+    References
+    ----------
+    Fortin, V.; Turcotte, R. Le modèle hydrologique MOHYSE. In Note de Cours Pour SCA7420,
+    Université du Québec à Montréal: Montréal, QC, Canada, 2007; p. 14.
+
+    Troin, M., Arsenault, R. and Brissette, F., 2015. Performance and uncertainty evaluation
+    of snow models on snowmelt flow simulations over a Nordic catchment (Mistassibi, Canada).
+    Hydrology, 2(4), pp.289-317.
+    """
+
     @dataclass
     class Params:
         par_x01: float
