@@ -1,27 +1,19 @@
 import datetime as dt
 import os
-import tempfile
 import zipfile
 from dataclasses import astuple, replace
 from pathlib import Path
 
 import numpy as np
 import pytest
-import xarray as xr
 
-from ravenpy.config.commands import (
+from ravenpy.config.commands import (  # GriddedForcingCommand,; LandUseClassesCommand,; ObservationDataCommand,; SoilClassesCommand,; SoilProfilesCommand,; VegetationClassesCommand,
     ChannelProfileCommand,
     EvaluationPeriod,
-    GriddedForcingCommand,
     GridWeightsCommand,
     HRUStateVariableTableCommand,
-    LandUseClassesCommand,
-    ObservationDataCommand,
     SBGroupPropertyMultiplierCommand,
-    SoilClassesCommand,
-    SoilProfilesCommand,
     Sub,
-    VegetationClassesCommand,
 )
 from ravenpy.config.rvs import RVI
 from ravenpy.models import (
@@ -46,7 +38,7 @@ TS = get_local_testdata(
 )
 
 # Link to THREDDS Data Server netCDF testdata
-TDS = "https://pavics.ouranos.ca/twitcher/ows/proxy/thredds/dodsC/birdhouse/testdata/raven"
+TDS = "https://pavics.ouranos.ca/twitcher/ows/proxy/thredds/dodsC/birdhouse/disk2/testdata/raven"
 
 
 @pytest.fixture
@@ -101,7 +93,7 @@ class TestGR4JCN:
 
     def test_simple(self):
         model = GR4JCN()
-
+        print(model.workdir)
         model.config.rvi.start_date = dt.datetime(2000, 1, 1)
         model.config.rvi.end_date = dt.datetime(2002, 1, 1)
         model.config.rvi.run_name = "test"
@@ -683,11 +675,13 @@ class TestGR4JCN:
             TS,
             start_date=dt.datetime(2000, 1, 1),
             end_date=dt.datetime(2002, 1, 1),
-            params=[
-                (0.529, -3.396, 407.29, 1.072, 16.9, 0.947),
-                (0.528, -3.4, 407.3, 1.07, 17, 0.95),
-            ],
             suppress_output=False,
+            parallel={
+                "params": [
+                    (0.529, -3.396, 407.29, 1.072, 16.9, 0.947),
+                    (0.528, -3.4, 407.3, 1.07, 17, 0.95),
+                ]
+            },
         )
 
         assert len(model.diagnostics) == 2
@@ -705,9 +699,9 @@ class TestGR4JCN:
             start_date=dt.datetime(2000, 1, 1),
             end_date=dt.datetime(2002, 1, 1),
             params=[0.529, -3.396, 407.29, 1.072, 16.9, 0.947],
-            nc_index=[0, 0],
             # name=["basin1", "basin2"],  # Not sure about this..
             suppress_output=False,
+            parallel={"nc_index": [0, 0]},
         )
 
         assert len(model.diagnostics) == 2
